/*
 * Copyright (C) 2012-2013 Daniel Medina <http://danielme.com>
 * 
 * This file is part of "Muspy for Android".
 * 
 * "Muspy for Android" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * "Muspy for Android" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with this program.  If not, see <http://www.gnu.org/licenses/gpl-3.0.html/>
 */
package com.danielme.muspyforandroid;

import com.danielme.muspyforandroid.utils.Utils;

import net.sf.andhsli.hotspotlogin.SimpleCryptoOld;
import net.sf.andhsli.hotspotlogin.SimpleCrypto;
import android.app.Application;
import android.content.Context;
import android.content.SharedPreferences;
import android.os.Build;
import android.util.Log;

/**
 * Global variables.
 * @author Daniel Medina (danielme.com)
 * @since 1.0
 */
public class MuspyApplication extends Application
{
	private String email = null;

	private String pass = null;

	private String userID = null;		
	
		
	public void setCredentials(String email, String pass, String userID)
	{
		this.email = email;		
		this.userID = userID;
		SharedPreferences sharedPreferences = getSharedPreferences(Constants.PREFS, Context.MODE_PRIVATE);
		SharedPreferences.Editor editor = sharedPreferences.edit();
		editor.putString(Constants.PREF_EMAIL, email);
		String passCryp = null;
		try
		{
			if (Build.VERSION.SDK_INT < Constants.API_421)
			{ 
				passCryp = SimpleCryptoOld.encrypt(Constants.SECRET.SEED, pass);
			}
			else
			{
				passCryp = SimpleCrypto.encrypt(Constants.SECRET.SEED, pass);

			}
		}
		catch (Exception e)
		{
			Log.e("encrypt error", "encrypt error", e);
			passCryp = pass;
		}
		this.pass = pass;
		editor.putString(Constants.PREF_PASS, passCryp);
		editor.putString(Constants.PREF_USERID, userID);
		editor.commit();
	}	

	public String getEmail()
	{
		if (email == null)
		{
			loadCredentials();
		}
		return email;
	}

	public void setEmail(String email)
	{
		this.email = email;
	}

	public String getPass()
	{
		if (pass == null)
		{
			loadCredentials();
		}
		return pass;
	}

	public void setPass(String pass)
	{
		this.pass = pass;
	}

	public String getUserID()
	{
		if (userID == null)
		{
			loadCredentials();
		}
		return userID;
	}

	public void setUserID(String userID)
	{
		this.userID = userID;
	}	
	
	private void loadCredentials()
	{
		Log.d(this.toString(), "loading credentials");
		SharedPreferences sharedPreferences = getSharedPreferences(Constants.PREFS, Context.MODE_PRIVATE);

		this.userID = sharedPreferences.getString(Constants.PREF_USERID, null);
		this.email = sharedPreferences.getString(Constants.PREF_EMAIL, null);
		String passPref = sharedPreferences.getString(Constants.PREF_PASS, null);
		if (Utils.hasText(passPref))
		{
			try
			{
				if (Build.VERSION.SDK_INT < 17)
				{
					this.pass = SimpleCryptoOld.decrypt(Constants.SECRET.SEED, passPref);
				}
				else
				{
					this.pass = SimpleCrypto.decrypt(Constants.SECRET.SEED, passPref);
				}
			}
			catch (Exception e)
			{
				Log.e(SimpleCryptoOld.class.toString(), "decrypt error", e);
				this.pass = passPref;
			}
		}
		else
		{
			this.pass = null;
		}
					
	}


}
