/*
 * Copyright (C) 2012-2013 Daniel Medina <http://danielme.com>
 * 
 * This file is part of "Muspy for Android".
 * 
 * "Muspy for Android" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * "Muspy for Android" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with this program.  If not, see <http://www.gnu.org/licenses/gpl-3.0.html/>
 */
package com.danielme.muspyforandroid.activities;


import com.danielme.muspyforandroid.Constants;
import com.danielme.muspyforandroid.R;
import com.danielme.muspyforandroid.activities.base.AbstractBrowserActivity;
import com.danielme.muspyforandroid.services.MusicBrainzClient;

import android.annotation.SuppressLint;
import android.app.AlertDialog;
import android.app.AlertDialog.Builder;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.graphics.Bitmap;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationSet;
import android.view.animation.LayoutAnimationController;
import android.view.animation.TranslateAnimation;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.RelativeLayout;

/**
 * 
 * @author Daniel Medina
 * @since 1.2
 *
 */
@SuppressLint("SetJavaScriptEnabled")
public class ArtistBioActivity extends AbstractBrowserActivity
{

	
	@Override
	protected void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.artistbio);
		markButtonPressed(R.id.artists, true);
		
		if (checkConnection())
		{
			String[] data = getIntent().getStringExtra(Constants.PARAM_ARTIST).split(Constants.INFO_SEPARATOR);
			browser = (WebView) findViewById(R.id.webkit);
			setTitle(getString(R.string.app_name) +" - " + data[1]);
			showProgressDialog(null);
			new LoadBio().execute(data[0]);
		}		
	}
	
	
	private class LoadBio extends AsyncTask<String, Void, String>
	{

		private String url = null;
		
		@Override
		protected String doInBackground(String... params)
		{			
			try
			{
				url = MusicBrainzClient.getInstance().getUrlWikipedia(params[0]);
				return null;
			}
			catch (Exception ex)
			{
				return ex.getMessage();
			}
		} 
		@Override
		protected void onPostExecute(String result)
		{
			if (result != null)
			{				
				getProgressDialog().dismiss();
				showError(null);
				
			}
			else if (url == null)
			{
				getProgressDialog().dismiss();
				Builder infoDialog = createInfoDialog(getString(R.string.nobio));
				infoDialog.setNeutralButton(getString(R.string.ok), new OnClickListener() {
					
					@Override
					public void onClick(DialogInterface dialog, int which)
					{					
						//nothing to see here, go back
						finish();
					}
				});			
				AlertDialog alertDialog = infoDialog.create();
				alertDialog.show();
				ArtistBioActivity.this.dialogStyle(alertDialog);
			}
			else
			{				
				browser.loadUrl(url + Constants.WIKIPEDIA_MOBILE);
				browser.getSettings().setJavaScriptEnabled(true);
				browser.setWebViewClient(new WebViewClient()
				{
					@Override
					public boolean shouldOverrideUrlLoading(WebView view, String url)
					{
						return false;
					}
					
					@Override
					public void onPageStarted(WebView view, String url, Bitmap favicon)
					{						
						super.onPageStarted(view, url, favicon);
						browser.setVisibility(View.VISIBLE);
					}
					
					
					@Override
					public void onPageFinished(WebView view, String url)
					{
						getProgressDialog().dismiss();
						
						//animation form bottom to top
						 AnimationSet set = new AnimationSet(true);
					     Animation animation = new TranslateAnimation(0.0f,0.0f,1.0f,0.0f);
					     animation.setDuration(300);
					     set.addAnimation(animation);

					     LayoutAnimationController controller = new LayoutAnimationController(set, 0.25f);
					     RelativeLayout bar = (RelativeLayout) findViewById(R.id.bar);
					     bar.setLayoutAnimation(controller);
					     bar.startAnimation(animation);
					     bar.setVisibility(View.VISIBLE);
					}
				});
			}
		}
		 
		
	}

}
